#!/usr/bin/perl
#
#	aix_iostat_stats.pl
#
#	This program will execute an iostat command and collect the info, total and average it
#	and finally pass it to the caller via a single line of output to stdout.  The iteration count
#	could be as many as desired, but only the last referenced disk data will be the stuff that is
#	retained and in the end, totaled and given to the caller.  Supposedly, the interval could be
#	whatever you wish as the iostat command does the data reduction to the per second value.
#
#	We skip data lines from iostat that are for cdrom devices.
#

open( IOS, "/usr/bin/iostat -d 4 2 |" ) || die("Cannot do iostat command");

$dcount = 0;
# Line item associative array.
$dsk  = 0;
$tma  = 0;
$kbps = 0;
$tps  = 0;
$kbr  = 0;
$kbr  = 0;
# Accumulators for Line items
$tot_tmact = 0;
$avg_tmact = 0;
$max_tmact = 0;
$tot_kbps  = 0;
$avg_kbps  = 0;
$max_kbps  = 0;
$tot_tps   = 0;
$avg_tps   = 0;
$max_tps   = 0;
$tot_kbr   = 0;
$avg_kbr   = 0;
$max_kbr   = 0;
$tot_kbw   = 0;
$avg_kbw   = 0;
$max_kbw   = 0;

while (<IOS>)
{
	chomp;
	next if ( m/^cd\d+\s+.*/ );
	if ( m/^(\S+\d+)\s+(-*\d+\.*\d*)\s+(-*\d+\.*\d*)\s+(-*\d+\.\d*)\s+(\d+)\s+(\d+)/ )
	{
		$dsk{"$1"}  = $1;
		$tma{"$1"}  = $2;
		$kbps{"$1"} = $3;
		$tps{"$1"}  = $4;
		$kbr{"$1"}  = $5;
		$kbw{"$1"}  = $6;
	}
}
close(IOS);
foreach $akey (sort keys(%dsk))
{
	$dcount++;
	$tot_tmact = $tot_tmact + $tma{$akey};
	$tot_kbps  = $tot_kbps  + $kbps{$akey};
	$tot_tps   = $tot_tps   + $tps{$akey};
	$tot_kbr   = $tot_kbr   + $kbr{$akey};
	$tot_kbw   = $tot_kbw   + $kbw{$akey};
	$max_tmact = $tma{$akey}  if ( $tma{$akey}  > $max_tmact );
	$max_kbps  = $kbps{$akey} if ( $kbps{$akey} > $max_kbps  );
	$max_tps   = $tps{$akey}  if ( $tps{$akey}  > $max_tps   );
	$max_kbr   = $kbr{$akey}  if ( $kbr{$akey}  > $max_kbr   );
	$max_kbw   = $kbw{$akey}  if ( $kbw{$akey}  > $max_kbw   );
}
if ( $dcount > 0 )
{
	$avg_tmact = int( ($tot_tmact / $dcount) * 10 ) / 10;
	$avg_kbps  = int( ($tot_kbps  / $dcount) * 10 ) / 10;
	$avg_tps   = int( ($tot_tps   / $dcount) * 10 ) / 10;
	$avg_kbr   = int( ($tot_kbr   / $dcount) * 10 ) / 10;
	$avg_kbw   = int( ($tot_kbw   / $dcount) * 10 ) / 10;
}
$pstr = "$dcount $avg_tmact $max_tmact ";
$pstr = $pstr . "$tot_kbps $avg_kbps $max_kbps $tot_tps $avg_tps $max_tps ";
$pstr = $pstr . "$tot_kbr $avg_kbr $max_kbr $tot_kbw $avg_kbw $max_kbw";
print "$pstr";
exit 0;
